@@ -651,7 +651,7 @@ class TestFormMixin(TestBase):
 
         response = self.view_get_ajax(TFormView)
         assert response['success']
-        assert 'form' in response
+        assert 'form_html' in response
         assert not response['redirect']
         
         response = self.view_get(TFormView)
