@@ -137,7 +137,10 @@ class MultipleFormatResponseMixin(TemplateResponseMixin):
         """
         Obtiene la respuesta de la vista en formato json
         """
-        
+
+        if 'form' in context:
+            del context['form']
+
         json_data = json.dumps(context)
         
         return HttpResponse(json_data, 'application/json')
